@@ -5,7 +5,7 @@
 //           This file provides an SIMD version of the functions.
 // Language: C
 // Date:     25-Mar-2020
-// Ver:      06-Sep-2021.
+// Ver:      31-Oct-2021.
 //
 //------------------------------------------------------------------------------
 //
@@ -82,7 +82,7 @@ int8x16_t initvec_signed_char(signed char initval) {
 void neg_signed_char_1_simd(Py_ssize_t arraylen, signed char *data) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -96,18 +96,18 @@ void neg_signed_char_1_simd(Py_ssize_t arraylen, signed char *data) {
 	alignedlength = calcalignedlength(arraylen, CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += CHARSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1q_s8( &data[index]);
+		datasliceleft = vld1q_s8( &data[x]);
 		// The actual SIMD operation. 
 		datasliceleft = vnegq_s8(datasliceleft);
 		// Store the result.
-		vst1q_s8( &data[index],  datasliceleft);
+		vst1q_s8( &data[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		data[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		data[x] = -data[x];
 	}
 
 }
@@ -119,7 +119,7 @@ void neg_signed_char_1_simd(Py_ssize_t arraylen, signed char *data) {
 void neg_signed_char_2_simd(Py_ssize_t arraylen, signed char *data, signed char *dataout) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -133,18 +133,18 @@ void neg_signed_char_2_simd(Py_ssize_t arraylen, signed char *data, signed char
 	alignedlength = calcalignedlength(arraylen, CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += CHARSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1q_s8( &data[index]);
+		datasliceleft = vld1q_s8( &data[x]);
 		// The actual SIMD operation. 
 		datasliceleft = vnegq_s8(datasliceleft);
 		// Store the result.
-		vst1q_s8( &dataout[index],  datasliceleft);
+		vst1q_s8( &dataout[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		dataout[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		dataout[x] = -data[x];
 	}
 
 }
@@ -162,7 +162,7 @@ void neg_signed_char_2_simd(Py_ssize_t arraylen, signed char *data, signed char
 char neg_signed_char_1_simd_ovfl(Py_ssize_t arraylen, signed char *data) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -182,9 +182,9 @@ char neg_signed_char_1_simd_ovfl(Py_ssize_t arraylen, signed char *data) {
 	alignedlength = calcalignedlength(arraylen, CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += CHARSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1q_s8( &data[index]);
+		datasliceleft = vld1q_s8( &data[x]);
 
 		// Check for overflow. 
 		// Do an equal compare operation.
@@ -205,13 +205,13 @@ char neg_signed_char_1_simd_ovfl(Py_ssize_t arraylen, signed char *data) {
 		datasliceleft = vnegq_s8(datasliceleft);
 
 		// Store the result.
-		vst1q_s8( &data[index],  datasliceleft);
+		vst1q_s8( &data[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		if ( minval_loop_willoverflow_signed_char(data[index]) ) {return ARR_ERR_OVFL;}
-		data[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		if ( minval_loop_willoverflow_signed_char(data[x]) ) {return ARR_ERR_OVFL;}
+		data[x] = -data[x];
 	}
 
 	return 0;
@@ -223,7 +223,7 @@ char neg_signed_char_1_simd_ovfl(Py_ssize_t arraylen, signed char *data) {
 char neg_signed_char_2_simd_ovfl(Py_ssize_t arraylen, signed char *data, signed char *dataout) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -243,9 +243,9 @@ char neg_signed_char_2_simd_ovfl(Py_ssize_t arraylen, signed char *data, signed
 	alignedlength = calcalignedlength(arraylen, CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += CHARSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1q_s8( &data[index]);
+		datasliceleft = vld1q_s8( &data[x]);
 
 		// Check for overflow. 
 		// Do an equal compare operation.
@@ -266,13 +266,13 @@ char neg_signed_char_2_simd_ovfl(Py_ssize_t arraylen, signed char *data, signed
 		datasliceleft = vnegq_s8(datasliceleft);
 
 		// Store the result.
-		vst1q_s8( &dataout[index],  datasliceleft);
+		vst1q_s8( &dataout[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		if ( minval_loop_willoverflow_signed_char(data[index]) ) {return ARR_ERR_OVFL;}
-		dataout[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		if ( minval_loop_willoverflow_signed_char(data[x]) ) {return ARR_ERR_OVFL;}
+		dataout[x] = -data[x];
 	}
 
 	return 0;
@@ -315,7 +315,7 @@ int16x8_t initvec_signed_short(signed short initval) {
 void neg_signed_short_1_simd(Py_ssize_t arraylen, signed short *data) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -329,18 +329,18 @@ void neg_signed_short_1_simd(Py_ssize_t arraylen, signed short *data) {
 	alignedlength = calcalignedlength(arraylen, SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += SHORTSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1q_s16( &data[index]);
+		datasliceleft = vld1q_s16( &data[x]);
 		// The actual SIMD operation. 
 		datasliceleft = vnegq_s16(datasliceleft);
 		// Store the result.
-		vst1q_s16( &data[index],  datasliceleft);
+		vst1q_s16( &data[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		data[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		data[x] = -data[x];
 	}
 
 }
@@ -352,7 +352,7 @@ void neg_signed_short_1_simd(Py_ssize_t arraylen, signed short *data) {
 void neg_signed_short_2_simd(Py_ssize_t arraylen, signed short *data, signed short *dataout) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -366,18 +366,18 @@ void neg_signed_short_2_simd(Py_ssize_t arraylen, signed short *data, signed sho
 	alignedlength = calcalignedlength(arraylen, SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += SHORTSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1q_s16( &data[index]);
+		datasliceleft = vld1q_s16( &data[x]);
 		// The actual SIMD operation. 
 		datasliceleft = vnegq_s16(datasliceleft);
 		// Store the result.
-		vst1q_s16( &dataout[index],  datasliceleft);
+		vst1q_s16( &dataout[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		dataout[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		dataout[x] = -data[x];
 	}
 
 }
@@ -395,7 +395,7 @@ void neg_signed_short_2_simd(Py_ssize_t arraylen, signed short *data, signed sho
 char neg_signed_short_1_simd_ovfl(Py_ssize_t arraylen, signed short *data) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -415,9 +415,9 @@ char neg_signed_short_1_simd_ovfl(Py_ssize_t arraylen, signed short *data) {
 	alignedlength = calcalignedlength(arraylen, SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += SHORTSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1q_s16( &data[index]);
+		datasliceleft = vld1q_s16( &data[x]);
 
 		// Check for overflow. 
 		// Do an equal compare operation.
@@ -438,13 +438,13 @@ char neg_signed_short_1_simd_ovfl(Py_ssize_t arraylen, signed short *data) {
 		datasliceleft = vnegq_s16(datasliceleft);
 
 		// Store the result.
-		vst1q_s16( &data[index],  datasliceleft);
+		vst1q_s16( &data[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		if ( minval_loop_willoverflow_signed_short(data[index]) ) {return ARR_ERR_OVFL;}
-		data[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		if ( minval_loop_willoverflow_signed_short(data[x]) ) {return ARR_ERR_OVFL;}
+		data[x] = -data[x];
 	}
 
 	return 0;
@@ -456,7 +456,7 @@ char neg_signed_short_1_simd_ovfl(Py_ssize_t arraylen, signed short *data) {
 char neg_signed_short_2_simd_ovfl(Py_ssize_t arraylen, signed short *data, signed short *dataout) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -476,9 +476,9 @@ char neg_signed_short_2_simd_ovfl(Py_ssize_t arraylen, signed short *data, signe
 	alignedlength = calcalignedlength(arraylen, SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += SHORTSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1q_s16( &data[index]);
+		datasliceleft = vld1q_s16( &data[x]);
 
 		// Check for overflow. 
 		// Do an equal compare operation.
@@ -499,13 +499,13 @@ char neg_signed_short_2_simd_ovfl(Py_ssize_t arraylen, signed short *data, signe
 		datasliceleft = vnegq_s16(datasliceleft);
 
 		// Store the result.
-		vst1q_s16( &dataout[index],  datasliceleft);
+		vst1q_s16( &dataout[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		if ( minval_loop_willoverflow_signed_short(data[index]) ) {return ARR_ERR_OVFL;}
-		dataout[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		if ( minval_loop_willoverflow_signed_short(data[x]) ) {return ARR_ERR_OVFL;}
+		dataout[x] = -data[x];
 	}
 
 	return 0;
@@ -548,7 +548,7 @@ int32x4_t initvec_signed_int(signed int initval) {
 void neg_signed_int_1_simd(Py_ssize_t arraylen, signed int *data) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -562,18 +562,18 @@ void neg_signed_int_1_simd(Py_ssize_t arraylen, signed int *data) {
 	alignedlength = calcalignedlength(arraylen, INTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += INTSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += INTSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1q_s32( &data[index]);
+		datasliceleft = vld1q_s32( &data[x]);
 		// The actual SIMD operation. 
 		datasliceleft = vnegq_s32(datasliceleft);
 		// Store the result.
-		vst1q_s32( &data[index],  datasliceleft);
+		vst1q_s32( &data[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		data[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		data[x] = -data[x];
 	}
 
 }
@@ -585,7 +585,7 @@ void neg_signed_int_1_simd(Py_ssize_t arraylen, signed int *data) {
 void neg_signed_int_2_simd(Py_ssize_t arraylen, signed int *data, signed int *dataout) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -599,18 +599,18 @@ void neg_signed_int_2_simd(Py_ssize_t arraylen, signed int *data, signed int *da
 	alignedlength = calcalignedlength(arraylen, INTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += INTSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += INTSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1q_s32( &data[index]);
+		datasliceleft = vld1q_s32( &data[x]);
 		// The actual SIMD operation. 
 		datasliceleft = vnegq_s32(datasliceleft);
 		// Store the result.
-		vst1q_s32( &dataout[index],  datasliceleft);
+		vst1q_s32( &dataout[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		dataout[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		dataout[x] = -data[x];
 	}
 
 }
@@ -628,7 +628,7 @@ void neg_signed_int_2_simd(Py_ssize_t arraylen, signed int *data, signed int *da
 char neg_signed_int_1_simd_ovfl(Py_ssize_t arraylen, signed int *data) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -648,9 +648,9 @@ char neg_signed_int_1_simd_ovfl(Py_ssize_t arraylen, signed int *data) {
 	alignedlength = calcalignedlength(arraylen, INTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += INTSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += INTSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1q_s32( &data[index]);
+		datasliceleft = vld1q_s32( &data[x]);
 
 		// Check for overflow. 
 		// Do an equal compare operation.
@@ -671,13 +671,13 @@ char neg_signed_int_1_simd_ovfl(Py_ssize_t arraylen, signed int *data) {
 		datasliceleft = vnegq_s32(datasliceleft);
 
 		// Store the result.
-		vst1q_s32( &data[index],  datasliceleft);
+		vst1q_s32( &data[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		if ( minval_loop_willoverflow_signed_int(data[index]) ) {return ARR_ERR_OVFL;}
-		data[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		if ( minval_loop_willoverflow_signed_int(data[x]) ) {return ARR_ERR_OVFL;}
+		data[x] = -data[x];
 	}
 
 	return 0;
@@ -689,7 +689,7 @@ char neg_signed_int_1_simd_ovfl(Py_ssize_t arraylen, signed int *data) {
 char neg_signed_int_2_simd_ovfl(Py_ssize_t arraylen, signed int *data, signed int *dataout) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -709,9 +709,9 @@ char neg_signed_int_2_simd_ovfl(Py_ssize_t arraylen, signed int *data, signed in
 	alignedlength = calcalignedlength(arraylen, INTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += INTSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += INTSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1q_s32( &data[index]);
+		datasliceleft = vld1q_s32( &data[x]);
 
 		// Check for overflow. 
 		// Do an equal compare operation.
@@ -732,13 +732,13 @@ char neg_signed_int_2_simd_ovfl(Py_ssize_t arraylen, signed int *data, signed in
 		datasliceleft = vnegq_s32(datasliceleft);
 
 		// Store the result.
-		vst1q_s32( &dataout[index],  datasliceleft);
+		vst1q_s32( &dataout[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		if ( minval_loop_willoverflow_signed_int(data[index]) ) {return ARR_ERR_OVFL;}
-		dataout[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		if ( minval_loop_willoverflow_signed_int(data[x]) ) {return ARR_ERR_OVFL;}
+		dataout[x] = -data[x];
 	}
 
 	return 0;
@@ -746,3 +746,200 @@ char neg_signed_int_2_simd_ovfl(Py_ssize_t arraylen, signed int *data, signed in
 }
 #endif
 
+
+/*--------------------------------------------------------------------------- */
+/* The following series of functions reflect the different parameter options possible.
+   arraylen = The length of the data arrays.
+   data = The input data array.
+   dataout = The output data array.
+*/
+// param_arr_none
+#if defined(AF_HASSIMD_ARM_AARCH64)
+void neg_float_1_simd(Py_ssize_t arraylen, float *data) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x4_t datasliceleft;
+
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceleft = vld1q_f32( &data[x]);
+		// The actual SIMD operation. 
+		datasliceleft = vnegq_f32(datasliceleft);
+		// Store the result.
+		vst1q_f32( &data[x], datasliceleft);
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		data[x] = -data[x];
+	}
+
+}
+
+
+
+// param_arr_arr
+void neg_float_2_simd(Py_ssize_t arraylen, float *data, float *dataout) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x4_t datasliceleft;
+
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceleft = vld1q_f32( &data[x]);
+		// The actual SIMD operation. 
+		datasliceleft = vnegq_f32(datasliceleft);
+		// Store the result.
+		vst1q_f32( &dataout[x], datasliceleft);
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		dataout[x] = -data[x];
+	}
+
+}
+#endif
+
+
+/*--------------------------------------------------------------------------- */
+/* The following series of functions reflect the different parameter options possible.
+   arraylen = The length of the data arrays.
+   data = The input data array.
+   dataout = The output data array.
+   Returns 1 if overflow occurred, else returns 0.
+*/
+// param_arr_none
+#if defined(AF_HASSIMD_ARM_AARCH64)
+char neg_float_1_simd_ovfl(Py_ssize_t arraylen, float *data) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x4_t datasliceleft, checkslice;
+
+	float checkvecresults[FLOATSIMDSIZE];
+	float checksliceinit[FLOATSIMDSIZE] = {0.0};
+
+
+	// This is used to check for errors by accumulating non-finite values.
+	checkslice = vld1q_f32( checksliceinit);
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceleft = vld1q_f32( &data[x]);
+		// The actual SIMD operation. 
+		datasliceleft = vnegq_f32(datasliceleft);
+		// Store the result.
+		vst1q_f32( &data[x], datasliceleft);
+
+		// Check the result. None-finite errors should accumulate.
+		checkslice = vmulq_f32(checkslice, datasliceleft);
+	}
+
+	// Check the results of the SIMD operations. If all is OK then the
+	// results should be all zeros. Any none-finite numbers however will
+	// propagate through and accumulate. 
+	vst1q_f32( checkvecresults, checkslice);
+	for (x = 0; x < FLOATSIMDSIZE; x++) {
+		if (!isfinite(checkvecresults[x])) {return 1;}
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		data[x] = -data[x];
+		if (!isfinite(data[x])) {return 1;}
+	}
+
+	// Everything was OK.
+	return 0;
+
+}
+
+
+
+// param_arr_arr
+char neg_float_2_simd_ovfl(Py_ssize_t arraylen, float *data, float *dataout) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x4_t datasliceleft, checkslice;
+
+	float checkvecresults[FLOATSIMDSIZE];
+	float checksliceinit[FLOATSIMDSIZE] = {0.0};
+
+
+	// This is used to check for errors by accumulating non-finite values.
+	checkslice = vld1q_f32( checksliceinit);
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceleft = vld1q_f32( &data[x]);
+		// The actual SIMD operation. 
+		datasliceleft = vnegq_f32(datasliceleft);
+		// Store the result.
+		vst1q_f32( &dataout[x], datasliceleft);
+
+		// Check the result. None-finite errors should accumulate.
+		checkslice = vmulq_f32(checkslice, datasliceleft);
+	}
+
+	// Check the results of the SIMD operations. If all is OK then the
+	// results should be all zeros. Any none-finite numbers however will
+	// propagate through and accumulate. 
+	vst1q_f32( checkvecresults, checkslice);
+	for (x = 0; x < FLOATSIMDSIZE; x++) {
+		if (!isfinite(checkvecresults[x])) {return 1;}
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		dataout[x] = -data[x];
+		if (!isfinite(dataout[x])) {return 1;}
+	}
+
+	// Everything was OK.
+	return 0;
+
+}
+#endif
+
